# heyyou - the "Hey, You!" program

`heyyou` is a command line application that prints out 'Hey, You!' in the chosen language.

Currently, `heyyou` supports the following languages and many more:
- English (EN)
- Spanish (ES)
- French (FR)
- German (DE)
- Italian (IT)

To use `heyyou` with a specific language, simply provide the language code as an argument. For example, to print "Hey, You!" in Italian, run `heyyou IT`.
Running `heyyou` without any argument will default to English, thus printing out `Hey, You!`

Enjoy using `heyyou` and spreading greetings in different languages!
